@@ -21,7 +21,7 @@ from cryptography.hazmat.primitives import hashes
 HTML_PATH = os.path.join( os.path.dirname(__file__) , "dist")
 
 class IOForm:
-    def __init__(self, port = 8000, config = {}, certfile = None, keyfile = None ):
+    def __init__(self, port = 8000, config = [], certfile = None, keyfile = None ):
         self.port = port
         self.certfile = certfile
         self.keyfile = keyfile
@@ -50,6 +50,10 @@ class IOForm:
     def put(self,msg):
         self.q_output.put(msg)
     
+    def input_rows(self,config):
+        msg = { "name":"input", "value":  { "input_rows": config } }
+        self.q_output.put(msg)
+
     def start_thread2(self):
         asyncio.run( self.start_thread() )
 
